<?php
/* Add custom field to WP Menu Editor */
class intheme_custom_nav_menu_walker extends Walker_Nav_Menu  {
	function start_el(&$output, $item, $depth, $args) {
	    global $_wp_nav_menu_max_depth;
	    $_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;
	    $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
	
	    ob_start();
	    $item_id = esc_attr( $item->ID );
	    $removed_args = array(
	        'action',
	        'customlink-tab',
	        'edit-menu-item',
	        'menu-item',
	        'page-tab',
	        '_wpnonce',
	    );
	
	    $original_title = '';
	    if ( 'taxonomy' == $item->type ) {
	        $original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
	        if ( is_wp_error( $original_title ) )
	            $original_title = false;
	    } elseif ( 'post_type' == $item->type ) {
	        $original_object = get_post( $item->object_id );
	        $original_title = $original_object->post_title;
	    }
	
	    $classes = array(
	        'menu-item menu-item-depth-' . $depth,
	        'menu-item-' . esc_attr( $item->object ),
	        'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
	    );
	
	    $title = $item->title;
	
	    if ( !empty( $item->_invalid ) ) {
	        $classes[] = 'menu-item-invalid';
	        /* translators: %s: title of menu item which is invalid */
	        $title = sprintf( __( '%s (Invalid)' ), $item->title );
	    } elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
	        $classes[] = 'pending';
	        /* translators: %s: title of menu item in draft status */
	        $title = sprintf( __('%s (Pending)'), $item->title );
	    }
	
	    $title = empty( $item->label ) ? $title : $item->label;
	    ?>
	    <li id="menu-item-<?php echo $item_id; ?>" class="<?php echo implode(' ', $classes ); ?>">
	        <dl class="menu-item-bar">
	            <dt class="menu-item-handle">
	                <span class="item-title"><?php echo esc_html( $title ); ?></span>
	                <span class="item-controls">
	                    <span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
	                    <span class="item-order hide-if-js">
	                        <a href="<?php
	                            echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-up-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            );
	                        ?>" class="item-move-up"><abbr title="<?php esc_attr_e('Move up'); ?>">&#8593;</abbr></a>
	                        |
	                        <a href="<?php
	                            echo wp_nonce_url(
	                                add_query_arg(
	                                    array(
	                                        'action' => 'move-down-menu-item',
	                                        'menu-item' => $item_id,
	                                    ),
	                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
	                                ),
	                                'move-menu_item'
	                            );
	                        ?>" class="item-move-down"><abbr title="<?php esc_attr_e('Move down'); ?>">&#8595;</abbr></a>
	                    </span>
	                    <a class="item-edit" id="edit-<?php echo $item_id; ?>" title="<?php esc_attr_e('Edit Menu Item'); ?>" href="<?php
	                        echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
	                    ?>"><?php _e( 'Edit Menu Item' ); ?></a>
	                </span>
	            </dt>
	        </dl>
	
	        <div class="menu-item-settings" id="menu-item-settings-<?php echo $item_id; ?>">
	            <?php if( 'custom' == $item->type ) : ?>
	                <p class="field-url description description-wide">
	                    <label for="edit-menu-item-url-<?php echo $item_id; ?>">
	                        <?php _e( 'URL' ); ?><br />
	                        <input type="text" id="edit-menu-item-url-<?php echo $item_id; ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
	                    </label>
	                </p>
	            <?php endif; ?>
	            <p class="description description-thin">
	                <label for="edit-menu-item-title-<?php echo $item_id; ?>">
	                    <?php _e( 'Navigation Label' ); ?><br />
	                    <input type="text" id="edit-menu-item-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
	                </label>
	            </p>
	            <p class="description description-thin">
	                <label for="edit-menu-item-attr-title-<?php echo $item_id; ?>">
	                    <?php _e( 'Title Attribute' ); ?><br />
	                    <input type="text" id="edit-menu-item-attr-title-<?php echo $item_id; ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
	                </label>
	            </p>
	            <p class="field-link-target description">
	                <label for="edit-menu-item-target-<?php echo $item_id; ?>">
	                    <input type="checkbox" id="edit-menu-item-target-<?php echo $item_id; ?>" value="_blank" name="menu-item-target[<?php echo $item_id; ?>]"<?php checked( $item->target, '_blank' ); ?> />
	                    <?php _e( 'Open link in a new window/tab' ); ?>
	                </label>
	            </p>
	            <p class="field-css-classes description description-thin">
	                <label for="edit-menu-item-classes-<?php echo $item_id; ?>">
	                    <?php _e( 'CSS Classes (optional)' ); ?><br />
	                    <input type="text" id="edit-menu-item-classes-<?php echo $item_id; ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo $item_id; ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
	                </label>
	            </p>
	            <p class="field-xfn description description-thin">
	                <label for="edit-menu-item-xfn-<?php echo $item_id; ?>">
	                    <?php _e( 'Link Relationship (XFN)' ); ?><br />
	                    <input type="text" id="edit-menu-item-xfn-<?php echo $item_id; ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
	                </label>
	            </p>
	            <p class="field-description description description-wide">
	                <label for="edit-menu-item-description-<?php echo $item_id; ?>">
	                    <?php _e( 'Description' ); ?><br />
	                    <textarea id="edit-menu-item-description-<?php echo $item_id; ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo $item_id; ?>]"><?php echo esc_html( $item->description ); // textarea_escaped ?></textarea>
	                    <span class="description"><?php _e('The description will be displayed in the menu if the current theme supports it.'); ?></span>
	                </label>
	            </p>        
<?php
/* ===========================
 * PRODUCT FILTER START
 * ===========================*/
if ( intheme_instamember() && function_exists('stms_get_products') ) {
	$products = stms_get_products();
	if ( $products ) :
		
?>
	<div class="description description-wide">
		<div class="menu_products" id="menu_products-<?php echo $item_id; ?>">
	        <label for="edit-menu-item-instaproduct-<?php echo $item_id; ?>">
	            <?php _e( 'Display menu only if has access to one of the following products' ); ?><br />
	            <select id="edit-menu-item-instaproduct-<?php echo $item_id; ?>" class="widefat menu-item-attr-product" name="menu-item-attr-product[<?php echo $item_id; ?>][]"  multiple>
	        	<?php foreach ( $products as $p ) {
	        		$selected = '';
					if ( !empty($item->products) && is_array($item->products) ) {
						$selected = ( in_array($p->ID, $item->products) ) ? ' selected="selected"' : '';
					}
	        		echo "<option value='{$p->ID}'{$selected}>" . stripslashes(esc_attr($p->title)) . "</option>";
	        	} ?>
	        	</select>
	        	<span class="description"><?php _e('Use "Ctrl+Click" to select multiple product or to unselect a product.'); ?></span>
	        </label>
		</div>
    </div>
<?php
	endif;
} 

/* ===========================
 * CUSTOM FIELD SECTION START
 * ===========================*/
 
			$num = 0;
			$preview = ( empty($item->icon) ) ? ' display:none;' : '';
?>
				<div class="description description-wide">
					<div class="menu_icons" id="menu_icons-<?php echo $item_id; ?>">
						<label for="edit-menu-item-icon-<?php echo $item_id; ?>"><em><?php _e('Icon URL'); ?></em><br />
							<span class="remove_icon" id="icon-remove-<?php echo $item_id; ?>" title="Remove this icon" data-itemid="<?php echo $item_id; ?>">&times;</span>
							<input type="text" id="edit-menu-item-icon-<?php echo $item_id; ?>" class="check_preview_input widefat code edit-menu-item-icon" name="menu-item-icon[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->icon ); ?>" title="Hover your mouse here to preview the icon" /> 
							<input id="upload-<?php echo $item_id; ?>" class="upload_image_button button" type="button" value="Upload Image" style="margin-top:5px;" /> or 
							<input alt="#TB_inline?height=450&amp;width=630&amp;inlineId=thickbox-<?php echo $item_id; ?>" title="Please CLICK on the icon to choose your preferred icon" class="thickbox button" type="button" value="Click here to show icons" />  
						</label>
			
						<table id="ibt-icon-preview-<?php echo $item_id; ?>" border="0" style="margin-top:5px;<?php echo $preview; ?>">
							<tbody>
								<tr>
									<td>You have selected this icon: </td>
									<td><img id="selected_icon-<?php echo $item_id; ?>" src="<?php echo esc_attr($item->icon); ?>" class="selected_icon" /></td>
									<td>&nbsp;</td>
								</tr>
							</tbody>
						</table>
			
						<div id="thickbox-<?php echo $item_id; ?>" style="display:none">
							<div class="frame_icons" id="frame_icons-<?php echo $item_id; ?>">
			<?php
								$icons = array();
								// opens images folder
								if ( $handle = opendir(INTHEME_PATH . 'images/icons-menu/24x24/') ) {
									$icon_dir = INTHEME_IMAGES . 'icons-menu/24x24/';
							    	while ( false !== ($file = readdir($handle)) ) {
										if ( $file != "." && $file != ".." ) {
											$icons[] = $icon_dir . $file;
							        	}
							    	}
							    	closedir($handle);
								}
						
								sort($icons);
								foreach ( $icons as $icon ) :
									$info = pathinfo($icon);
									$icon_name = @$info['filename'];
									$num++;
			?>
									<label for="icon-<?php echo $num . '-' . $item_id; ?>" data-item="<?php echo $item_id; ?>">
										<span><?php echo $icon_name; ?></span><br />
										<img class="image<?php echo $item_id; ?>" src="<?php echo $icon; ?>" alt="icon-<?php echo $num .'-'. $item_id; ?>" />
									</label>
								<?php endforeach; ?>
								<div style="clear:both;"></div>
							</div>
							
						</div>
					</div>
				</div>
<?php
/* ===========================
 * END OF CUSTOM FIELD SECTION
 * ===========================*/
?>
		        <div class="menu-item-actions description-wide submitbox">
		            <?php if( 'custom' != $item->type && $original_title !== false ) : ?>
		                <p class="link-to-original">
		                    <?php printf( __('Original: %s'), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
		                </p>
		            <?php endif; ?>
		            <a class="item-delete submitdelete deletion" id="delete-<?php echo $item_id; ?>" href="<?php
		            echo wp_nonce_url(
		                add_query_arg(
		                    array(
		                        'action' => 'delete-menu-item',
		                        'menu-item' => $item_id,
		                    ),
		                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
		                ),
		                'delete-menu_item_' . $item_id
		            ); ?>"><?php _e('Remove'); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo $item_id; ?>" href="<?php echo esc_url( add_query_arg( array('edit-menu-item' => $item_id, 'cancel' => time()), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
		                ?>#menu-item-settings-<?php echo $item_id; ?>"><?php _e('Cancel'); ?></a>
		        </div>
		
		        <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo $item_id; ?>]" value="<?php echo $item_id; ?>" />
		        <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
		        <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
		        <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
		        <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
		        <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo $item_id; ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
		    </div><!-- .menu-item-settings-->
		    <ul class="menu-item-transport"></ul>
<?php
			$output .= ob_get_clean();
	}
}

/* Menu custom fields update functions */
add_action('wp_update_nav_menu_item', 'intheme_update_nav_icon',10, 3);
function intheme_update_nav_icon( $menu_id, $menu_item_db_id, $args ) {
	if ( isset($_REQUEST['menu-item-attr-product']) ) {
		if ( is_array($_REQUEST['menu-item-attr-product'][$menu_item_db_id]) ) {
			update_post_meta( $menu_item_db_id, '_menu_item_attr_product', $_REQUEST['menu-item-attr-product'][$menu_item_db_id] );
		}
	}
	
    if ( isset($_REQUEST['menu-item-icon']) && is_array($_REQUEST['menu-item-icon']) ) {
        $icon_value = $_REQUEST['menu-item-icon'][$menu_item_db_id];
        update_post_meta( $menu_item_db_id, '_menu_item_icon', $icon_value );
    }
}

/* Adds value of new field to $item object that will be passed to Walker_Nav_Menu_Edit_Custom */
add_filter('wp_setup_nav_menu_item', 'intheme_nav_icon_item');
function intheme_nav_icon_item( $menu_item ) {
    $menu_item->icon = get_post_meta($menu_item->ID, '_menu_item_icon', true);
	$menu_item->products = get_post_meta($menu_item->ID, '_menu_item_attr_product', true);
    return $menu_item;
}


add_filter('wp_edit_nav_menu_walker', 'intheme_nav_icon_edit_walker', 10, 2);
function intheme_nav_icon_edit_walker($walker,$menu_id) {
    return 'intheme_custom_nav_menu_walker';
}

add_filter('wp_edit_nav_menu_walker', 'intheme_nav_custom_icon_edit_walker', 10, 2);
function intheme_nav_custom_icon_edit_walker($walker,$menu_id) {
    return 'intheme_custom_nav_menu_walker';
}