<?php
add_action('intheme_header', 'instaglow_header');
function instaglow_header() {
	global $intheme;
	$logo = ( !empty($intheme['logo']) ) ? '<img src="' . intheme_sanitize($intheme['logo']) . '" border="0" />' : '<span>' . get_bloginfo('name') . '</span>';
?>
	<nav class="navbar navbar-default" role="navigation">
	  	<div class="navbar-header">
			<button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
			  	<span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
			</button>
			<a class="navbar-brand" href="<?php echo esc_url(home_url('/')); ?>" title="<?php echo esc_attr(get_bloginfo('name', 'display')); ?>" rel="home"><?php echo $logo; ?></a>
	  	</div><!-- /.navbar-header -->

		<!-- Collect the nav links, forms, and other content for toggling -->
		<div class="navbar-collapse collapse">
			<?php intheme_top_menu(); ?>
		</div><!-- /.navbar-collapse -->
	</nav>

<?php
}

add_action('intheme_top_menu', 'instaglow_top_menu');
function instaglow_top_menu() {
	$location = ( intheme_member_logged_in() ) ? 'menu-2' : 'menu-1';
	$args = array(
		'theme_location' => $location,
		'container' => '',
		'menu_id' => 'member-menu',
		'menu_class' => 'menu nav navbar-nav navbar-right',
		'walker' => new instatheme_nav_menu_walker
	);
	if ( has_nav_menu($location) ) wp_nav_menu($args);
}

add_action('intheme_before_widgets', 'instabright_member_profile', 5);
function instabright_member_profile() {
	if ( !intheme_member_logged_in() ) return '';
	
	$member = intheme_currentmember();
	$profile_url = ( intheme_instamember() && function_exists('stms_get_handler_url') ) ? stms_get_handler_url('profile') : admin_url('profile.php');
	$logout_url = ( intheme_instamember() && function_exists('stms_get_handler_url') ) ? stms_get_handler_url('logout') : wp_logout_url();

	global $lldocroot;
	$configFileName = $lldocroot . "/dap/dap-config.php";
	$is_dap = false;
	if ( !intheme_instamember() && file_exists($configFileName) ) {
		$logout_url = "/dap/logout.php";
		$is_dap = true;
	}
?>
<div class="userdata">
    <div class="userdata_format">
        <div class="userinfo">
            <?php echo get_avatar($member['email'], 90); ?><br />
			<h4>Welcome <?php echo $member['display_name']; ?></h4>
			<?php if ( !$is_dap ) : ?><a href="<?php echo $profile_url; ?>">Profile</a> | <?php endif; ?><a href="<?php echo $logout_url; ?>">Log out</a>
        </div>
        <div style="clear:left"></div>
    </div>
</div>
<?php
}

add_filter('get_avatar','instabright_gravatar_class');
function instabright_gravatar_class($class) {
    $class = str_replace("class='avatar", "class='avatar img-circle", $class);
    return $class;
}

add_action('intheme_sidebar_menu', 'instaglow_sidebar_menu');
function instaglow_sidebar_menu() {
	if ( !intheme_member_logged_in() ) return;
	$args = array(
		'theme_location' => 'menu-5',
		'container' => 'div',
		'container_class' => 'member_menu_sidebar',
		'menu_id' => '',
		'menu_class' => 'list',
		'depth' => 2,
		'walker' => new instatheme_sidebar_menu_walker
	);
	
	if ( has_nav_menu('menu-5') ) {
		//echo '<h3>' . __('Site Navigation', 'instatheme') . '</h3>';
		wp_nav_menu($args);
	}
}

add_action('intheme_member_menu', 'instaglow_member_menu');
function instaglow_member_menu() {
	if ( !intheme_member_logged_in() ) return;
	$args = array(
		'theme_location' => 'menu-6',
		'container' => '',
		'container_id' => '',
		'container_class' => '',
		'menu_id' => 'menutop',
		'menu_class' => 'menutop',
		'depth' => 1,
		'walker' => new instaglow_nav_menu_walker
	);
	if ( has_nav_menu('menu-6') ) wp_nav_menu($args);
}

if ( !function_exists('external_dynamic_css') ) :
add_action('wp_head', 'external_dynamic_css', 98);
function external_dynamic_css() {
	global $intheme;
	
	if ( !is_array($intheme) )
		return;
	
	$data = $intheme;
	$theme_color = ( !empty($data['theme_color']) ) ? intheme_sanitize($data['theme_color']) : $data['theme_color_pre'];
	if ( empty($theme_color) ) {
		// use default color;
		$theme_color = '#95b400';
	}
	$content_bgcolor = ( !empty($data['content_bgcolor']) ) ? intheme_sanitize($data['content_bgcolor']) : $data['content_bgcolor_pre'];
	$header_bgcolor = intheme_sanitize($data['header_bgcolor']);
	
	$custom_header = $data['custom_header'];
	$custom_footer = $data['custom_footer'];
	$custom_sidebar = $data['custom_sidebar'];
	$custom_link = $data['custom_link'];
	$custom_content = $data['custom_content'];
	
	$ia_background = !empty($data['stripebar_background']) ? $data['stripebar_background'] : '#fcf8e3';
	$ia_color = !empty($data['stripebar_color']) ? $data['stripebar_color'] : '#c09853';
	$ia_border = !empty($data['stripebar_border']) ? $data['stripebar_border'] : '#c09853';
	
?>
<style type="text/css">
/* InstaAttention */
.woahbar,
.woahbar-inner,
.show-notify {
	background-color: <?php echo $ia_background; ?>;
	color: <?php echo $ia_color; ?>;
	border-color: <?php echo $ia_border; ?> !important;
}

.woahbar a,
.woahbar-inner a {
	color: <?php echo $ia_color; ?> !important;
	text-decoration:none;
}
.woahbar a:hover,
.woahbar-inner a:hover {
	border-bottom:none !important;
	text-decoration:none !important;
}

<?php 
$enable_hh = ( !empty($data['enable_header_height']) ) ? $data['enable_header_height'] : 0;
$header_height = ( !empty($data['header_height']) ) ? $data['header_height'] : '';
	
if ( !empty($header_height) && $enable_hh ) : 
	$logo_height = $header_height - 12; 
	$padding_top = ceil(($header_height*25)/100);
?>

/* Header */
.navbar-default {
	min-height: <?php echo $header_height; ?>px;
}
.navbar-default .navbar-brand img {
	max-height: <?php echo $logo_height; ?>px;
}

/* navbar links */
.navbar-default .nav > li > a,
.navbar-default .nav > li > a.dropdown-toggle {
	padding-top: <?php echo $padding_top; ?>px;
	height: <?php echo $header_height; ?>px;
}

<?php endif; ?>

/* Main Color Theme */
.navbar-default,
#sidebar h2, #sidebar h3,
#site-footer,
#sidebar .member_menu_sidebar ul,
#menutop li:hover,
#menutop li.current-menu-item,
#back-top a:hover {
	background-color: <?php echo $theme_color; ?>;
}

.pagination a { color: <?php echo $theme_color; ?>; }
.navbar-default,
#site-footer,
#menutop li:hover,
#menutop li.current-menu-item {
	border-color: <?php echo $theme_color; ?>;
}

<?php if ( $custom_content ) : ?>
/* Content Background Color */
.site-content { background-color: <?php echo $content_bgcolor; ?>; }
<?php endif; // custom content ?>

<?php if ( $custom_link ) : ?>
/* Link Color */
a { color: <?php echo intheme_sanitize($data['textlink_color']); ?>; }
a:hover { color: <?php echo intheme_sanitize($data['textlink_colorhover']); ?>; }
<?php endif; // custom link ?>

<?php if ( $custom_sidebar ) : ?>
/* Sidebar Background */
#sidebar { background-color: <?php echo intheme_sanitize($data['sidebar_bgcolor']); ?>; }
<?php endif; // custom sidebar ?>

<?php if ( $custom_header ) : ?>
/* Header Background */
.navbar-default { background-color: <?php echo $header_bgcolor; ?>; }
<?php if ( !empty($data['header_image']) ) : ?>
.navbar-default {
	background: <?php echo $header_bgcolor; ?> url('<?php echo intheme_sanitize($data['header_image']); ?>') top left repeat !important;
}
<?php endif; ?>

/* Header Text Color */
.navbar-default,
.navbar-default .nav > li > a,
.navbar-default .nav > li > a.dropdown-toggle,
.navbar-default .navbar-brand {
	color: <?php echo intheme_sanitize($data['header_fontcolor']); ?>;
}

<?php endif; // custom header ?>

<?php if ( $custom_footer ) : ?>
/* Footer Background Color */
#site-footer { background-color: <?php echo intheme_sanitize($data['footer_bgcolor']); ?>; }
/* Footer Text Color */
#site-footer,
#site-footer .menufooter li a,
#site-footer a {
	color: <?php echo intheme_sanitize($data['footer_fontcolor']); ?>;
}
<?php endif; // custom footer ?>

<?php if ( !empty($intheme['custom_css']) ) : ?>
/* Custom CSS */
<?php echo esc_html(intheme_sanitize($intheme['custom_css'])); ?>
<?php endif; ?>

</style>
<?php	
}
endif;

/* Navigation Class */
if ( !class_exists('instaglow_nav_menu_walker') ) :
class instaglow_nav_menu_walker extends Walker_Nav_Menu {
    // add classes to ul sub-menus
	function start_lvl( &$output, $depth ) {
	    // depth dependent classes
	    $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
	    $display_depth = ( $depth + 1); // because it counts the first submenu as 0
	    $classes = array(
	        'dropdown-menu',
	        ( $display_depth % 2  ? 'menu-odd' : 'menu-even' ),
	        ( $display_depth >=2 ? 'sub-sub-menu' : '' ),
	        'menu-depth-' . $display_depth
	    );
	    $class_names = implode( ' ', $classes );
	  
	    // build html
	    $output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
	}
	
	// add main/sub classes to li's and links
    function start_el( &$output, $item, $depth, $args ) {
		global $wp_query;
    	$indent = ( $depth > 0 ? str_repeat( "\t", $depth ) : '' ); // code indent
  
	    // depth dependent classes
	    $depth_classes = array(
	        ( $depth == 0 ? 'main-menu-item' : 'sub-menu-item' ),
	        ( $depth >= 2 ? 'sub-sub-menu-item' : '' ),
	        ( $depth % 2 ? 'menu-item-odd' : 'menu-item-even' ),
	        'menu-item-depth-' . $depth
	    );
    	$depth_class_names = esc_attr( implode( ' ', $depth_classes ) );
	
		// passed classes
    	$classes = empty( $item->classes ) ? array() : (array) $item->classes;
    	$class_names = esc_attr( implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) ) );
			
		// build html
    	$output .= $indent . '<li id="menu-item-'. $item->ID . '" class="' . $depth_class_names . ' ' . $class_names . '">';
	
        $attributes  = '';
        $attributes .= !empty($item->attr_title) ? ' title="'  . esc_attr($item->attr_title) . '"' : '';
        $attributes .= !empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
        $attributes .= !empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
		$attributes .= !empty($item->url) ? ' href="' . esc_attr($item->url) .'"' : '';
		$attributes .= ( 0 == $depth && in_array('dropdown', $classes) ) ? ' class="dropdown-toggle" data-toggle="dropdown" data-hover="dropdown" data-delay="500" data-close-others="false"' : '';
		//$attributes .= ' class="menu-link ' . ( $depth > 0 ? 'sub-menu-link' : 'main-menu-link' ) . '"';
		
        // Insert description for top level elements only
        $description = ( !empty($item->description) and 0 == $depth ) ? '<small class="nav_desc">' . esc_attr( $item->description ) . '</small>' : '';
        $title = apply_filters( 'the_title', $item->title, $item->ID );
        $icon = ( !empty( $item->icon ) and 0 == $depth ) ? '<img src="' . esc_attr( $item->icon ) . '" alt="'.$title.'">' : '';
		$caret = ( 0 == $depth && in_array('dropdown', $classes) ) ? ' <b class="caret"></b>' : '';
		
        $item_output = $args->before
            . "<a $attributes>"
            . $icon
 			. $args->link_before
            . $title
            . $caret
            . '</a>'
            . $args->link_after
            //. $description
            . $args->after;
	
        // Since $output is called by reference we don't need to return anything.
        $output .= apply_filters(
			'walker_nav_menu_start_el',
			$item_output,
			$item,
			$depth,
			$args
        );
    }
}
endif;